OllamaClient class

Constructors

OllamaClient({String endpoint = 'http://localhost:11434/api/generate', String model = 'deepseek-coder'})

Properties

endpoint → String
final
hashCode → int
The hash code for this object.
no setterinherited
model → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate(String prompt) → Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited