UnitTestGenerator class
Generates unit test files by delegating to UnitTestTemplate.
Constructors
Properties
- className → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- importPath → String
-
final
- isTopLevel → bool
-
final
-
methods
→ List<
String> -
final
- mockClassName → String?
-
final
- mockImportPath → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generate(
) → String - Generates the complete unit test file content.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited