WidgetTestGenerator class
Generates widget test files by delegating to WidgetTestTemplate.
Constructors
- WidgetTestGenerator({required String widgetName, required String importPath, bool isConst = true})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- importPath → String
-
final
- isConst → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widgetName → String
-
final
Methods
-
generate(
) → String - Generates the complete widget test file content.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited