ServiceDetector class

Detects service, repository, controller, BLoC, and Cubit classes by analyzing the class name suffix and extends/implements clauses.

Constructors

ServiceDetector()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

detect(ClassDeclaration node) → ServiceType
Returns the service type for a given class declaration.
isServiceClass(ClassDeclaration node) → bool
Returns true if the class is a service, repository, controller, etc.
label(ServiceType type) → String
Returns a human-readable label for the detected type.