isServiceClass static method
Returns true if the class is a service, repository, controller, etc.
Implementation
static bool isServiceClass(ClassDeclaration node) {
return detect(node) != ServiceType.none;
}
Returns true if the class is a service, repository, controller, etc.
static bool isServiceClass(ClassDeclaration node) {
return detect(node) != ServiceType.none;
}