UiElement class

Models detected UI elements in a Flutter widget tree.

Constructors

UiElement({required String type, String? label})

Properties

hashCode → int
The hash code for this object.
no setterinherited
label → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited