AiTestGenerator class
AI-powered test generation using DeepSeek Coder via Ollama.
Constructors
- AiTestGenerator({OllamaClient? client})
Properties
- client → OllamaClient
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generateFullTest(
String sourceCode, String filePath, {List< UiElement> ? uiElements}) → Future<String?> - Generates an AI-assisted test using local Ollama.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited