Logger class
Colored, structured CLI logger for kvs_testsmith.
Constructors
- Logger()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
divider(
) → void -
error(
String message) → void -
header(
String title) → void -
info(
String message) → void -
step(
String message) → void -
success(
String message) → void -
summary(
{required int filesScanned, required int widgetsFound, required int servicesFound, required int widgetTestsGenerated, required int unitTestsGenerated, required int skipped}) → void - Prints a summary block with stats.
-
warning(
String message) → void