PathMapper class
Maps source file paths in lib/ to their corresponding test file paths
in test/, preserving the directory structure.
Constructors
- PathMapper(String projectRoot)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectRoot → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getImportPath(
String libPath, String packageName) → String - Returns the package import path for a given source file.
-
getLibPath(
String testPath) → String - Maps a test file back to its corresponding source file.
-
getTestPath(
String libPath) → String -
Maps a source file in
lib/to its corresponding test file intest/. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited