ProjectScanner class
Recursively scans the lib/ directory for Dart source files,
filtering out generated files and ignored directories.
Constructors
- ProjectScanner(String projectRoot)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectRoot → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
hasTestFile(
String testPath) → bool - Checks whether a test file already exists for the given test path.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
scanLib(
) → List< File> -
Recursively scans
lib/and returns all eligible Dart source files. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited