WidgetDetector class
Detects whether a class is a Flutter StatelessWidget or StatefulWidget
by inspecting its extends clause.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
detect(
ClassDeclaration node) → WidgetType - Returns the widget type for a given class declaration.
-
isWidget(
ClassDeclaration node) → bool -
Returns
trueif the class is a StatelessWidget or StatefulWidget.